@@ -1,4 +1,4 @@
-from utils import standardize, getDailyVol
+from .utils import standardize, getDailyVol
 
 from lumnisfactors import LumnisFactors
 
@@ -467,4 +467,4 @@ class AlpacaLumnisTrader():
             df_live.index                     = pd.to_datetime(df_live.index, utc=True)
         
             self.price_history[asset.symbol]  = pd.concat([self.price_history[asset.symbol], df_live], axis=0)
-            self.price_history[asset.symbol]  = self.price_history[asset.symbol][~self.price_history[asset.symbol].index.duplicated(keep='first')].sort_index()
\ No newline at end of file
+            self.price_history[asset.symbol]  = self.price_history[asset.symbol][~self.price_history[asset.symbol].index.duplicated(keep='first')].sort_index()
